gedidb.CMRQuery
===============

.. currentmodule:: gedidb

.. autoclass:: CMRQuery

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~CMRQuery.__init__
   
   

   
   
   